@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Ouch;
-$Ouch::VERSION = '0.0409';
+$Ouch::VERSION = '0.0410';
 use Carp qw(longmess shortmess);
 use parent 'Exporter';
 use overload bool => sub {1}, q{""} => 'scalar', fallback => 1;
@@ -34,7 +34,7 @@ sub throw {  # alias
 
 sub kiss {
   my ($code, $e) = @_;
-  $e ||= $@;
+  $e = $@ if @_ < 2;
   if (blessed $e && $e->isa('Ouch') && $e->code eq $code) {
     return 1;
   }
@@ -50,9 +50,8 @@ sub caught {
 }
 
 sub hug {
-  my ($e) = @_;
-  $e ||= $@;
-  return $@ ? 1 : 0;
+  my $e = @_ ? $_[0] : $@;
+  return $e ? 1 : 0;
 }
 
 sub catch_all {
@@ -64,13 +63,12 @@ sub caught_all {
 }
 
 sub bleep {
-  my ($e) = @_;
-  $e ||= $@;
+  my $e = @_ ? $_[0] : $@;
   if (blessed $e && $e->isa('Ouch')) {
     return $e->message;
   }
   else {
-    my $message = $@;
+    my $message = "$e"; # force to string anyway
     if ($message =~ m{^(.*)\s+at\s.*line\s\d+.}xms) {
         return $1;
     }
@@ -81,12 +79,11 @@ sub bleep {
 }
 
 sub barf {
-    my ($e) = @_;
+    my $e = @_ ? $_[0] : $@;
     my $code;
-    $e ||= $@;
     if (blessed $e && $e->isa('Ouch')) {
         $code = $e->code;
-    } 
+    }
     else {
         $code = 1;
     }
@@ -135,7 +132,7 @@ Ouch - Exceptions that don't hurt.
 
 =head1 VERSION
 
-version 0.0409
+version 0.0410
 
 =head1 SYNOPSIS
 
